@@ -20,7 +20,8 @@ FormHome::FormHome(QWidget *parent) :
 
     ui->setupUi(this);
     group_model = new QSqlQueryModel();
-    group_model->setQuery(DML_GROUP_LIST);
+
+    updateQueries();
     ui->listViewGroups->setModel(group_model);
     ui->listViewGroups->setModelColumn(1);
 
@@ -33,24 +34,21 @@ FormHome::~FormHome()
 
 void FormHome::on_listWidgetHome_activated(const QModelIndex &index)
 {
+
     switch(index.row()){
     case 0:
-        //INBOX
         launchInbox();
         break;
     case 1:
-        //LATE
         launchLate();
         break;
     case 2:
-        //TODAY
         launchToday();
         break;
     case 3:
-        //TOMORROW
         launchTomorrow();
         break;
-    case 4: //TASKS
+    case 4:
         launchTasks();
         break;
     case 5:
@@ -59,36 +57,29 @@ void FormHome::on_listWidgetHome_activated(const QModelIndex &index)
     default:
         return;
     }
+
 }
 
 void FormHome::launchInbox(){
 
-    if(!nav){
-        nav = new FormTaskListNavigator(this);
-    }
+    getNav();
 
     nav->setSQLWhereClause("(Type = '2' OR Type ='3') AND id NOT IN (SELECT Id FROM FolderItem)");
     nav->updateQuery();
     nav->setAttribute(Qt::WA_Maemo5StackedWindow);
     nav->setWindowFlags(nav->windowFlags() | Qt::Window);
     nav->setWindowTitle("Inbox");
-    nav->hideFolderButton(true);
-    nav->hideNoteButton(false);
     nav->show();
 }
 
 void FormHome::launchTasks(){
-    if(!nav){
-        nav = new FormTaskListNavigator(this);
-    }
+    getNav();
 
     nav->setSQLWhereClause("(Type = '2')");
     nav->updateQuery();
     nav->setAttribute(Qt::WA_Maemo5StackedWindow);
     nav->setWindowFlags(nav->windowFlags() | Qt::Window);
     nav->setWindowTitle("Tasks");
-    nav->hideFolderButton(true);
-    nav->hideNoteButton(true);
     nav->show();
 }
 
@@ -97,9 +88,7 @@ void FormHome::launchLate(){
     QDateTime now;
     int i = now.currentDateTime().toUTC().toTime_t();
 
-    if(!nav){
-        nav = new FormTaskListNavigator(this);
-    }
+    getNav();
     cout << "NOW is: " << i << endl;
     int j = i - 43200;
     QString clause = "Type = '2' AND DateStart < " % QString::number(j) % " AND Status=0";
@@ -108,24 +97,16 @@ void FormHome::launchLate(){
     nav->setAttribute(Qt::WA_Maemo5StackedWindow);
     nav->setWindowFlags(nav->windowFlags() | Qt::Window);
     nav->setWindowTitle("Late");
-    nav->hideFolderButton(true);
-    nav->hideNoteButton(true);
     nav->show();
 
 }
 
 void FormHome::launchToday(){
 
-    if(!nav){
-        nav = new FormTaskListNavigator(this);
-    }
+    getNav();
 
-    QDateTime now;
-    //86400 is one day, 43200
-    int i = now.currentDateTime().toUTC().toTime_t();
-    cout << "NOW is: " << i << endl;
-    int j = i - 43200;
-    int k = i + 43200;
+    int j = QDateTime(QDate::currentDate()).toUTC().toTime_t();
+    int k = j + 86399;
 
     QString clause = "Type = '2' AND DateStart BETWEEN " % QString::number(j) % " AND " % QString::number(k) % " AND Status=0";
     nav->setSQLWhereClause(clause);
@@ -133,8 +114,8 @@ void FormHome::launchToday(){
     nav->setAttribute(Qt::WA_Maemo5StackedWindow);
     nav->setWindowFlags(nav->windowFlags() | Qt::Window);
     nav->setWindowTitle("Today");
-    nav->hideFolderButton(true);
-    nav->hideNoteButton(true);
+    //nav->hideFolderButton(true);
+    //nav->hideNoteButton(true);
     cout << "HOLA" << endl;
     nav->show();
 
@@ -142,50 +123,38 @@ void FormHome::launchToday(){
 }
 
 void FormHome::launchTomorrow(){
-    QDateTime now;
-    int i = now.currentDateTime().toUTC().toTime_t();
+    getNav();
 
-    if(!nav){
-        nav = new FormTaskListNavigator(this);
-    }
-    cout << "NOW is: " << i << endl;
-    int j = i + 43200;
-    QString clause = "Type = '2' AND DateStart > " % QString::number(j) % " AND Status=0";
+    int j = QDateTime(QDate::currentDate().addDays(1)).toUTC().toTime_t();
+    int k = j + 86399;
+
+    QString clause = "Type = '2' AND DateStart BETWEEN " % QString::number(j) % " AND " % QString::number(k) % " AND Status=0";
     nav->setSQLWhereClause(clause);
     nav->updateQuery();
     nav->setAttribute(Qt::WA_Maemo5StackedWindow);
     nav->setWindowFlags(nav->windowFlags() | Qt::Window);
     nav->setWindowTitle("Tomorrow");
-    nav->hideFolderButton(true);
-    nav->hideNoteButton(true);
     nav->show();
 }
 
 void FormHome::launchNotes(){
-    if(!nav){
-        nav = new FormTaskListNavigator(this);
-    }
+    getNav();
 
     nav->setSQLWhereClause("(Type = '3')");
     nav->updateQuery();
     nav->setAttribute(Qt::WA_Maemo5StackedWindow);
     nav->setWindowFlags(nav->windowFlags() | Qt::Window);
     nav->setWindowTitle("Notes");
-    nav->hideFolderButton(true);
-    nav->hideNoteButton(false);
-    nav->hideTaskButton(true);
+    //nav->hideFolderButton(true);
+    //nav->hideNoteButton(false);
+    //nav->hideTaskButton(true);
     nav->show();
 }
 
 void FormHome::on_listViewGroups_activated(const QModelIndex &index)
 {
     int folderId = index.sibling(index.row(),0).data().toInt();
-
-
-    if(!nav){
-        nav = new FormTaskListNavigator(this);
-    }
-
+    getNav();
     nav->setFolderId(folderId);
 
     QString f = QString::number(folderId);
@@ -201,7 +170,6 @@ void FormHome::on_listViewGroups_activated(const QModelIndex &index)
     nav->hideFolderButton(false);
     nav->hideNoteButton(false);
     nav->show();
-    group_model->setQuery(DML_GROUP_LIST); //process any deletes down the chain.
 }
 
 void FormHome::on_pushButton_2_clicked()
@@ -223,7 +191,7 @@ void FormHome::on_pushButton_2_clicked()
                     QMaemo5InformationBox::information(this,"Failed to create folder!");
                 } else {
                     ok = false;
-                    group_model->setQuery(DML_GROUP_LIST);
+                    updateQueries();
                 }
             }
         }
@@ -233,5 +201,20 @@ void FormHome::on_pushButton_2_clicked()
 void FormHome::on_pushButton_clicked()
 {
     TaskEditor te;
-    te.addTask();
+    te.addTask(0);
+}
+
+void FormHome::getNav(){
+
+    if(!nav){
+        nav = new FormTaskListNavigator(this);
+        connect(nav,SIGNAL(folderAddedOrRemoved()),SLOT(updateQueries()));
+    }
+    nav->setFolderId(0);
+}
+
+void FormHome::updateQueries(){
+    cout << "&&&&&&&&&&&&&&&&&&&&&&&&&&&&&& updateQueries() !!!" << endl;
+    group_model->clear();
+    group_model->setQuery(DML_GROUP_LIST);  //requery if user created/deleted a folder whilst in the views
 }
