@@ -25,6 +25,11 @@ public:
 
     void setFolderId(int FolderId);
 
+signals:
+    void folderAddedOrRemoved();
+    void folderAdded(int FolderId);
+    void folderRemoved(int FolderId);
+
 private slots:
     void on_buttonTask_clicked();
 
